==> enterprisemodules-db2_config-0.3.0.tar.gz: enterprisemodules-db2_config-0.3.0/lib/puppet/type/pcmkr_database.rb <==
# frozen_string_literal: true

#
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'
require 'puppet_x/enterprisemodules/db2/core'

Puppet::Type.newtype(:pcmkr_database) do
  include EasyType
  include PuppetX::EnterpriseModules::Db2::Type

  def self.module_name
    'db2_config'
  end

  desc <<-DESC
  This resource allows you to manage an Pacemaker cluster. Here is an example on how to use this:

      pcmkr_database { 'db2inst1/MYDB':
        ensure     => 'present',
      }

  All of these properties are read-only. If you need to add nodes, or change interfaces, the cluster
  must be recreated. At this point in time Puppet does not take care of this.

  DESC

  to_get_raw_resources do
    pcmkr_databases
  end

  ensurable

  on_create do
    Puppet.debug Puppet::Util::Execution.execute("#{location}/bin/db2cm -create -db #{database_name} -instance #{instance_name}")
  end

  on_modify do
    fail 'At this point in time Pacemaker does not support modifying databases.'
  end

  on_destroy do
    Puppet.debug Puppet::Util::Execution.execute("#{location}/bin/db2cm -delete -db #{database_name} -instance #{instance_name}")
  end

  map_titles_to_attributes([%r{((.*)/(.*))}, [:name, :instance_name, :database_name]])

  parameter :name
  parameter :instance_name
  parameter :database_name
  parameter :location

  property :managed
  property :primary_instance
  property :primary_node
  property :primary_state
  property :standby_instance
  property :standby_node
  property :standby_state
end

==> enterprisemodules-db2_config-1.0.1.tar.gz: enterprisemodules-db2_config-1.0.1/lib/puppet/type/pcmkr_database.rb <==
# frozen_string_literal: true

#
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'
require 'puppet_x/enterprisemodules/db2/core'

Puppet::Type.newtype(:pcmkr_database) do
  include EasyType
  include PuppetX::EnterpriseModules::Db2::Type

  def self.module_name
    'db2_config'
  end

  desc <<-DESC
  This resource allows you to manage an Pacemaker cluster. Here is an example on how to use this:

      pcmkr_database { 'db2inst1/MYDB':
        ensure     => 'present',
      }

  All of these properties are read-only. If you need to add nodes, or change interfaces, the cluster
  must be recreated. At this point in time Puppet does not take care of this.

  DESC

  to_get_raw_resources do
    pcmkr_databases
  end

  ensurable

  on_create do
    Puppet.debug Puppet::Util::Execution.execute("#{actual_location}/bin/db2cm -create -db #{database_name} -instance #{instance_name}")
  end

  on_modify do
    fail 'At this point in time Pacemaker does not support modifying databases.'
  end

  on_destroy do
    Puppet.debug Puppet::Util::Execution.execute("#{actual_location}/bin/db2cm -delete -db #{database_name} -instance #{instance_name}")
  end

  map_titles_to_attributes([%r{((.*)/(.*))}, [:name, :instance_name, :database_name]])

  parameter :name
  parameter :instance_name
  parameter :database_name
  parameter :location

  property :managed
  property :primary_instance
  property :primary_node
  property :primary_state
  property :standby_instance
  property :standby_node
  property :standby_state
end
